@@ -22,14 +22,14 @@
 #ifndef TESTSEASONS_H
 #define TESTSEASONS_H
 
-#include <QObject>
+#include <QtCore/QObject>
 
 class SeasonsTest : public QObject
 {
     Q_OBJECT
 private Q_SLOTS:
-    void test_data();
-    void test();
+    void test2005();
+    void test2007();
 };
 
 #endif
